==> system-keyboard-qt_21.02.04.tar.xz: system-keyboard-qt/translations/system-keyboard-qt_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>SelectLayoutDialog</name>
    <message>
        <location filename="selectlayoutdialog.ui" line="14"/>
        <source>Select Keyboard Layout and Variant</source>
        <translation>Klavye Düzenini ve Türevini Seçin</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.ui" line="29"/>
        <source>Layout</source>
        <translation>Düzen</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.ui" line="47"/>
        <source>Variants</source>
        <translation>Türevler</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.cpp" line="57"/>
        <source>No Variant</source>
        <translation>Türev Yok</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="window.ui" line="14"/>
        <location filename="window.cpp" line="113"/>
        <location filename="window.cpp" line="117"/>
        <source>System Keyboard</source>
        <translation>Sistem Klavyesi</translation>
    </message>
    <message>
        <location filename="window.ui" line="28"/>
        <source>Layouts</source>
        <translation>Düzenler</translation>
    </message>
    <message>
        <location filename="window.ui" line="34"/>
        <source>Keyboard Model</source>
        <translation>Klavye Türü</translation>
    </message>
    <message>
        <location filename="window.ui" line="55"/>
        <source>search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="window.ui" line="68"/>
        <source>Keyboard Layouts</source>
        <translation>Klavye Düzenleri</translation>
    </message>
    <message>
        <location filename="window.ui" line="158"/>
        <source>Hotkeys</source>
        <translation>Kısayollar</translation>
    </message>
    <message>
        <location filename="window.ui" line="181"/>
        <source>Advanced</source>
        <translation>Gelişmiş</translation>
    </message>
    <message>
        <location filename="window.ui" line="209"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="window.cpp" line="186"/>
        <location filename="window.cpp" line="204"/>
        <location filename="window.cpp" line="241"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="window.cpp" line="186"/>
        <location filename="window.cpp" line="204"/>
        <location filename="window.cpp" line="241"/>
        <source>Failed to open file: </source>
        <translation>Dosyayı açma başarısız oldu:</translation>
    </message>
    <message>
        <location filename="window.cpp" line="241"/>
        <source>Most settings will not be loaded</source>
        <translation>Çoğu ayar yüklenmeyecek</translation>
    </message>
    <message>
        <location filename="window.cpp" line="352"/>
        <source>Disabled</source>
        <translation>Devre dışı</translation>
    </message>
</context>
</TS>

==> system-keyboard-qt_2023.04.12.tar.xz: system-keyboard-qt/translations/system-keyboard-qt_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>SelectLayoutDialog</name>
    <message>
        <location filename="selectlayoutdialog.ui" line="14"/>
        <source>Select Keyboard Layout and Variant</source>
        <translation>Klavye Düzenini ve Türevini Seçin</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.ui" line="29"/>
        <source>Layout</source>
        <translation>Düzen</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.ui" line="47"/>
        <source>Variants</source>
        <translation>Türevler</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.cpp" line="57"/>
        <source>No Variant</source>
        <translation>Türev Yok</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="window.ui" line="14"/>
        <location filename="window.cpp" line="113"/>
        <location filename="window.cpp" line="117"/>
        <source>System Keyboard</source>
        <translation>Sistem Klavyesi</translation>
    </message>
    <message>
        <location filename="window.ui" line="28"/>
        <source>Layouts</source>
        <translation>Düzenler</translation>
    </message>
    <message>
        <location filename="window.ui" line="34"/>
        <source>Keyboard Model</source>
        <translation>Klavye Türü</translation>
    </message>
    <message>
        <location filename="window.ui" line="55"/>
        <source>search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <location filename="window.ui" line="68"/>
        <source>Keyboard Layouts</source>
        <translation>Klavye Düzenleri</translation>
    </message>
    <message>
        <location filename="window.ui" line="158"/>
        <source>Hotkeys</source>
        <translation>Kısayollar</translation>
    </message>
    <message>
        <location filename="window.ui" line="181"/>
        <source>Advanced</source>
        <translation>Gelişmiş</translation>
    </message>
    <message>
        <location filename="window.ui" line="209"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="window.cpp" line="186"/>
        <location filename="window.cpp" line="204"/>
        <location filename="window.cpp" line="241"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="window.cpp" line="186"/>
        <location filename="window.cpp" line="204"/>
        <location filename="window.cpp" line="241"/>
        <source>Failed to open file: </source>
        <translation>Dosyayı açma başarısız oldu:</translation>
    </message>
    <message>
        <location filename="window.cpp" line="241"/>
        <source>Most settings will not be loaded</source>
        <translation>Çoğu ayar yüklenmeyecek</translation>
    </message>
    <message>
        <location filename="window.cpp" line="352"/>
        <source>Disabled</source>
        <translation>Devre dışı</translation>
    </message>
</context>
</TS>
